@@ -1,5 +1,4 @@
 import asyncio
-import time
 
 from .sequential import SequentialRecipe
 
@@ -7,10 +6,10 @@ from .sequential import SequentialRecipe
 class LeaderElection(SequentialRecipe):
 
     def __init__(self, base_path):
-        super(LeaderElection, self).__init__(base_path)
+        super().__init__(base_path)
         self.has_leadership = False
 
-        self.leadership_future = asyncio.Future()
+        self.leadership_future = self.client.loop.create_future()
 
     async def join(self):
         await self.create_unique_znode("candidate")
@@ -30,18 +29,14 @@ class LeaderElection(SequentialRecipe):
             return
 
         await self.wait_on_sibling(candidates[position - 1])
-        asyncio.ensure_future(self.check_position())
+        asyncio.ensure_future(self.check_position(), loop=self.client.loop)
 
     async def wait_for_leadership(self, timeout=None):
         if self.has_leadership:
             return
 
-        time_limit = None
-        if timeout is not None:
-            time_limit = time.time() + timeout
-
-        if time_limit:
-            await asyncio.wait_for(self.leadership_future, time_limit)
+        if timeout:
+            await asyncio.wait_for(self.leadership_future, timeout)
         else:
             await self.leadership_future
 
